@@ -14,6 +14,17 @@ from setuptools.command import easy_install as easy_install_pkg
 from setuptools.dist import Distribution
 
 
+def setup_module(module):
+    packages = 'stevedore', 'virtualenvwrapper', 'pbr', 'novaclient'
+    for pkg in packages:
+        try:
+            __import__(pkg)
+            tmpl = "Integration tests cannot run when {pkg} is installed"
+            pytest.skip(tmpl.format(**locals()))
+        except ImportError:
+            pass
+
+
 @pytest.fixture
 def install_context(request, tmpdir, monkeypatch):
     """Fixture to set up temporary installation directory.
@@ -25,6 +36,9 @@ def install_context(request, tmpdir, monkeypatch):
     install_dir = tmpdir.mkdir('install_dir')
 
     def fin():
+        # undo the monkeypatch, particularly needed under
+        # windows because of kept handle on cwd
+        monkeypatch.undo()
         new_cwd.remove()
         user_base.remove()
         user_site.remove()
@@ -68,7 +82,6 @@ def test_virtualenvwrapper(install_context):
                  'virtualenvwrapper', 'hook_loader.py')
 
 
-@pytest.mark.xfail
 def test_pbr(install_context):
     _install_one('pbr', install_context,
                  'pbr', 'core.py')
